@@ -254,7 +254,8 @@ def git_pull_request(target_remote=None, target_branch=None,
                      fork=True,
                      setup_only=False,
                      branch_prefix=None,
-                     dry_run=False):
+                     dry_run=False,
+                     labels=None):
     branch = git_get_branch_name()
     if not branch:
         LOG.critical("Unable to find current branch")
@@ -326,7 +327,7 @@ def git_pull_request(target_remote=None, target_branch=None,
         retcode = fork_and_push_pull_request(
             g, hosttype, repo, rebase, target_remote, target_branch, branch,
             user, title, message, comment, force_editor, tag_previous_revision,
-            fork, setup_only, branch_prefix, dry_run,
+            fork, setup_only, branch_prefix, dry_run, labels,
         )
 
     approve_login_password(host=hostname, user=user, password=password)
@@ -360,7 +361,8 @@ def download_pull_request(g, repo, target_remote, pull_number,
             _run_shell_command(["git", "remote", "add", remote_name,
                                 pull.head.repo.clone_url])
         _run_shell_command(["git", "fetch", remote_name])
-        _run_shell_command(["git", "branch", "-u", "origin", pull.base.ref])
+        _run_shell_command(["git", "branch", "-u", "origin/%s" % pull.base.ref,
+                            local_branch_name])
 
 
 def edit_file_get_content_and_remove(filename):
@@ -386,6 +388,9 @@ def find_pull_request_template():
         filename,
         os.path.join(".github", filename),
         os.path.join("docs", filename),
+        filename.lower(),
+        os.path.join(".github", filename.lower()),
+        os.path.join("docs", filename.lower()),
     ]
     for path in pr_template_paths:
         templates = glob.glob(path)
@@ -431,7 +436,8 @@ def fork_and_push_pull_request(g, hosttype, repo_to_fork, rebase,
                                title, message, comment,
                                force_editor, tag_previous_revision, fork,
                                setup_only, branch_prefix,
-                               dry_run=False):
+                               dry_run=False,
+                               labels=None):
 
     g_user = g.get_user()
 
@@ -510,7 +516,6 @@ def fork_and_push_pull_request(g, hosttype, repo_to_fork, rebase,
     if dry_run:
         LOG.info("Would force-push branch `%s' to remote `%s/%s'",
                  branch, remote_to_push, remote_branch)
-        return
     else:
         LOG.info("Force-pushing branch `%s' to remote `%s/%s'",
                  branch, remote_to_push, remote_branch)
@@ -524,6 +529,10 @@ def fork_and_push_pull_request(g, hosttype, repo_to_fork, rebase,
                                         head=head))
     if pulls:
         for pull in pulls:
+            if dry_run:
+                LOG.info("Pull-request would be updated:\n  %s", pull.html_url)
+                continue
+
             LOG.info("Pull-request updated:\n  %s", pull.html_url)
 
             if force_editor:
@@ -539,12 +548,21 @@ def fork_and_push_pull_request(g, hosttype, repo_to_fork, rebase,
             elif message:
                 pull.edit(body=message)
                 LOG.debug("Updated pull-request message")
-        if comment:
-            # FIXME(jd) we should be able to comment directly on a PR without
-            # getting it as an issue but pygithub does not allow that yet
-            repo_to_fork.get_issue(pull.number).create_comment(comment)
-            LOG.debug("Commented: \"%s\"", comment)
+
+            if comment:
+                # FIXME(jd) we should be able to comment directly on a PR
+                # without getting it as an issue but pygithub does not allow
+                # that yet
+                repo_to_fork.get_issue(pull.number).create_comment(comment)
+                LOG.debug("Commented: \"%s\"", comment)
+
+            if labels:
+                LOG.debug("Adding labels %s", labels)
+                pull.add_to_labels(*labels)
     else:
+        if dry_run:
+            LOG.info("Pull-request would be created.")
+            return
         # Create a pull request
         if force_editor or not (title and message):
             nb_of_commits, git_title, git_message = git_get_title_and_message(
@@ -576,6 +594,10 @@ def fork_and_push_pull_request(g, hosttype, repo_to_fork, rebase,
         else:
             LOG.info("Pull-request created: %s", pull.html_url)
 
+        if labels:
+            LOG.debug("Adding labels %s", labels)
+            pull.add_to_labels(*labels)
+
     if tag_previous_revision:
         preserve_older_revision(branch, remote_to_push)
 
@@ -631,6 +653,9 @@ def build_parser():
                         help="Title of the pull request.")
     parser.add_argument("--message", "-m",
                         help="Message of the pull request.")
+    parser.add_argument("--label", "-l", action='append',
+                        help="The labels to add to the pull request. "
+                        "Can be used multiple times.")
     git_config_add_argument(parser,
                             "--branch-prefix",
                             help="Prefix remote branch")
@@ -711,6 +736,7 @@ def main():
             setup_only=args.setup_only,
             branch_prefix=args.branch_prefix,
             dry_run=args.dry_run,
+            labels=args.label,
         )
     except Exception:
         LOG.error("Unable to send pull request", exc_info=True)
